[jboss-cvs] JBossAS SVN: r84456 - in projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss: deployers/spi/management/deploy and 1 other directories.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Thu Feb 19 08:25:29 EST 2009


Author: emuckenhuber
Date: 2009-02-19 08:25:29 -0500 (Thu, 19 Feb 2009)
New Revision: 84456

Modified:
   projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/deployers/spi/management/ManagementView.java
   projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/deployers/spi/management/deploy/DeploymentID.java
   projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/deployers/spi/management/deploy/DeploymentManager.java
   projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/deployers/spi/management/deploy/DeploymentTarget.java
   projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/profileservice/spi/DeploymentRepository.java
   projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/profileservice/spi/Profile.java
Log:
[JBAS-6526] remove DeploymentPhase

Modified: projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/deployers/spi/management/ManagementView.java
===================================================================
--- projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/deployers/spi/management/ManagementView.java	2009-02-19 13:20:07 UTC (rev 84455)
+++ projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/deployers/spi/management/ManagementView.java	2009-02-19 13:25:29 UTC (rev 84456)
@@ -92,12 +92,11 @@
     * Get a deployment
     * 
     * @param name the name
-    * @param phase the phase
     * @return the deployment
     * @throws NoSuchDeploymentException if no matches are found 
     * @throws Exception for any error
     */
-   public ManagedDeployment getDeployment(String name, DeploymentPhase phase)
+   public ManagedDeployment getDeployment(String name)
       throws NoSuchDeploymentException, Exception;
 
 
@@ -175,25 +174,22 @@
 
    /**
     * 
-    * @param phase
     * @param deploymentBaseName
     * @param info
     * @throws Exception
     */
-   public void applyTemplate(DeploymentPhase phase,
-         String deploymentBaseName, DeploymentTemplateInfo info)
-         throws Exception;
+   public void applyTemplate( String deploymentBaseName, DeploymentTemplateInfo info)
+    throws Exception;
 
    /**
     * Remove a deployment
     * 
     * @param deploymentName the deployment name
-    * @param phase the phase
     * @throws NoSuchProfileException
     * @throws NoSuchDeploymentException
     * @throws Exception for any error
     */
-   public void removeDeployment(String deploymentName, DeploymentPhase phase)
+   public void removeDeployment(String deploymentName)
       throws NoSuchDeploymentException, Exception;
 
    /**

Modified: projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/deployers/spi/management/deploy/DeploymentID.java
===================================================================
--- projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/deployers/spi/management/deploy/DeploymentID.java	2009-02-19 13:20:07 UTC (rev 84455)
+++ projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/deployers/spi/management/deploy/DeploymentID.java	2009-02-19 13:25:29 UTC (rev 84456)
@@ -56,12 +56,6 @@
    public void setRepositoryNames(String[] names);
 
    /**
-    * Get the phase the deployment is associated with
-    * @return
-    */
-   DeploymentPhase getPhase();
-
-   /**
     * An optional content URL used for distribute/redeploy operations.
     * @return
     */

Modified: projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/deployers/spi/management/deploy/DeploymentManager.java
===================================================================
--- projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/deployers/spi/management/deploy/DeploymentTarget.java	2009-02-19 13:20:07 UTC (rev 84455)
+++ projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/deployers/spi/management/deploy/DeploymentTarget.java	2009-02-19 13:25:29 UTC (rev 84456)
@@ -21,7 +21,6 @@
  */
 package org.jboss.deployers.spi.management.deploy;
 
-import org.jboss.managed.api.ManagedDeployment.DeploymentPhase;
 
 /**
  * A target to which a deployment is uploaded.
@@ -39,10 +38,11 @@
    String getName();
 
    
+   String[] getRepositoryNames(String[] names)
+      throws Exception;
+
    void distribute(DeploymentID deployment)
       throws Exception;
-   String[] getRepositoryNames(String[] names, DeploymentPhase phase)
-      throws Exception;
    void redeploy(DeploymentID deployment)
       throws Exception;
    void prepare(DeploymentID deployment)
@@ -50,9 +50,9 @@
    void start(DeploymentID deployment)
       throws Exception;
    void stop(DeploymentID deployment)
-   throws Exception;
-   void undeploy(DeploymentID deployment)
       throws Exception;
+   void remove(DeploymentID deployment)
+      throws Exception;
 
    /**
     * Get the target description

Modified: projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/profileservice/spi/DeploymentRepository.java
===================================================================
--- projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/profileservice/spi/DeploymentRepository.java	2009-02-19 13:20:07 UTC (rev 84455)
+++ projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/profileservice/spi/DeploymentRepository.java	2009-02-19 13:25:29 UTC (rev 84456)
@@ -84,6 +84,15 @@
     * @return
     */
    public Set<String> getDeploymentNames();
+   
+   /**
+    * Get repository names.
+    *
+    * @param names the names
+    * @return full repository names
+    * @throws Exception for any error
+    */
+   public String[] getRepositoryNames(String... names) throws Exception;
 
    /**
     * Upload raw deployment content to a profile repository. This does not make

Modified: projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/profileservice/spi/Profile.java
===================================================================
--- projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/profileservice/spi/Profile.java	2009-02-19 13:20:07 UTC (rev 84455)
+++ projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/profileservice/spi/Profile.java	2009-02-19 13:25:29 UTC (rev 84456)
@@ -24,8 +24,6 @@
 import java.util.Collection;
 import java.util.Set;
 
-import org.jboss.managed.api.ManagedComponent;
-
 /**
  * A profile represents a named collection of deployments on a server
  * 
@@ -82,19 +80,6 @@
     * @throws Exception for any error
     */
    void addDeployment(ProfileDeployment d) throws Exception;
-   
-   /**
-    * Update a deployment. This can be used to save attachments, other
-    * metadata of the deployment.
-    * 
-    * @param d the deployment
-    * @param phase - the phase of the deployment as it relates to when the
-    * deployment is loaded
-    * @param attachments - the attachments that have been modified
-    * @throws Exception for any error
-    */
-   @Deprecated
-   void updateDeployment(ProfileDeployment d, ManagedComponent comp) throws Exception;
 
    /**
     * Remove a deployment
@@ -145,7 +130,6 @@
     * @see #getModifiedDeployments
     * @param flag - the enable/disable flag
     */
-   @Deprecated
    void enableModifiedDeploymentChecks(boolean flag);
 
    /**




More information about the jboss-cvs-commits mailing list
--- projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/deployers/spi/management/deploy/DeploymentManager.java	2009-02-19 13:20:07 UTC (rev 84455)
+++ projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/deployers/spi/management/deploy/DeploymentManager.java	2009-02-19 13:25:29 UTC (rev 84456)
@@ -23,13 +23,13 @@
 
 import java.net.URL;
 
-import org.jboss.managed.api.ManagedDeployment.DeploymentPhase;
 import org.jboss.profileservice.spi.ProfileKey;
 
 /**
  * An interface for uploading and controlling deployments in a profile.
  * 
  * @author Scott.Stark at jboss.org
+ * @author <a href="mailto:emuckenh at redhat.com">Emanuel Muckenhuber</a>
  * @version $Revision:$
  */
 public interface DeploymentManager
@@ -58,38 +58,22 @@
    /**
     * Add raw deployment content to the profile.
     * 
-    * @param name phase unique name
-    * @param phase the phase this deployment applies to
+    * @param name the deployment name
     * @param contentURL - URL for obtaining the deployment archive
-    * @return DeploymentProgress progress object for the deployment
-    */
-   @Deprecated
-   public DeploymentProgress distribute(String name, DeploymentPhase phase, URL contentURL)
-      throws Exception;
-
-   /**
-    * Add raw deployment content to the profile.
-    *
-    * @param name phase unique name
-    * @param phase the phase this deployment applies to
-    * @param contentURL - URL for obtaining the deployment archive
     * @param copyContent should we copy content or just reference it
-    * @return DeploymentProgress progress object for the deployment
+    * @return a DeploymentProgress used to run and track the distribute progress.
     */
-   public DeploymentProgress distribute(String name, DeploymentPhase phase,
-         URL contentURL, boolean copyContent)
-      throws Exception;
+   public DeploymentProgress distribute(String name, URL contentURL, boolean copyContent);
 
    /**
     * Map from the external name passed to distribute to the uploaded
     * deployment repository name.
     * 
     * @param names - the list of external deployment names
-    * @param phase the deployment phase
     * @return the mapped list of unique names in the deployment repository.
     * @throws Exception for any error
     */
-   public String[] getRepositoryNames(String[] names, DeploymentPhase phase) throws Exception;
+   public String[] getRepositoryNames(String[] names) throws Exception;
 
    /**
     * Is redeploy supported.
@@ -97,59 +81,37 @@
     * @return true if redeploy suported
     */
    public boolean isRedeploySupported();
-
+   
    /**
     * Do redeploy.
-    *
+    * 
     * @param name the deployment to redeploy
-    * @param phase the deployment phase
-    * @param contentURL deployment's url
     * @return a DeploymentProgress used to run and track the redeploy progress.
     */
-   public DeploymentProgress redeploy(String name, DeploymentPhase phase, URL contentURL)
-      throws Exception;
-
+   public DeploymentProgress redeploy(String name);
+   
    /**
-    * Prepare a set of deployments through their dependency analysis phase.
-    *
-    * @param phase the deployment phase
-    * @param names the unique names of the deployments within the phase to prepare
-    * @return a DeploymentProgress used to run and track the prepare progress.
-    * @throws Exception for any error
-    */
-   public DeploymentProgress prepare(DeploymentPhase phase, String... names)
-      throws Exception;
-
-   /**
-    * Start a previously distributed deployment.
-    *
-    * @param phase the deployment phase
+    * Start a previously distributed deployment. 
+    * 
     * @param names the unique names of the deployments within the phase to start
     * @return a DeploymentProgress used to run and track the start progress.
-    * @throws Exception for any error
     */
-   public DeploymentProgress start(DeploymentPhase phase, String... names)
-      throws Exception;
-
+   public DeploymentProgress start(String... names);
+   
    /**
     * Stop a previously started deployment.
-    *
-    * @param phase the deployment phase
+    * 
     * @param names the unique names of the deployments within the phase to stop
     * @return a DeploymentProgress used to run and track the stop progress.
-    * @throws Exception for any error
     */
-   public DeploymentProgress stop(DeploymentPhase phase, String... names)
-      throws Exception;
-
+   public DeploymentProgress stop(String... names);
+   
    /**
     * Undeploy a previously distributed deployment.
     *
     * @param phase the deployment phase
     * @param names the unique names of the deployments within the phase to prepare
     * @return a DeploymentProgress used to run and track the prepare progress.
     * @throws Exception for any error
     */
-   public DeploymentProgress undeploy(DeploymentPhase phase, String... names)
-      throws Exception;
+   public DeploymentProgress remove(String... names);
+   
 }
@@ -97,59 +81,37 @@
    /**
-    * Undeploy a previously distributed deployment.
-    *
-    * @param phase the deployment phase
+    * Remove a previously distributed deployment.
+    * 
     * @param names the unique names of the deployments within the phase to prepare
@@ -97,59 +81,37 @@
     * @param names the unique names of the deployments within the phase to prepare
-    * @return a DeploymentProgress used to run and track the prepare progress.
-    * @throws Exception for any error
+    * @return a DeploymentProgress used to run and track the remove progress.
     */

Modified: projects/integration/trunk/jboss-profileservice-spi/src/main/java/org/jboss/deployers/spi/management/deploy/DeploymentTarget.java
===================================================================